@@ -82,6 +82,10 @@
 #'   for \code{formula} but is included for consistency with
 #'   \code{ggplot2::stat_smooth()}.
 #'
+#'   R option \code{OutDec} is obeyed based on its value at the time the plot
+#'   is rendered, i.e., displayed or printed. Set \code{options(OutDec = ",")}
+#'   for languages like Spanish or French.
+#'
 #' @details This stat can be used to automatically annotate a plot with rho or
 #'   the fitted model equation. The model fitting is done using package
 #'  'quantreg', please, consult its documentation for the
@@ -231,13 +235,13 @@
 #'
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_quant_line(formula = formula, size = 0.5) +
+#'   stat_quant_line(formula = formula, linewidth = 0.5) +
 #'   stat_quant_eq(formula = formula)
 #'
 #' # angle
 #' ggplot(my.data, aes(x, y)) +
 #'   geom_point() +
-#'   stat_quant_line(formula = formula) +
+#'   stat_quant_line(formula = formula, linewidth = 0.5) +
 #'   stat_quant_eq(formula = formula, angle = 90, hstep = 0.05, vstep = 0,
 #'                 label.y = 0.98, hjust = 1)
 #'
@@ -264,12 +268,12 @@
 #' # grouping
 #' ggplot(my.data, aes(x, y2, color = group)) +
 #'   geom_point() +
-#'   stat_quant_line(formula = formula, size = 0.5) +
+#'   stat_quant_line(formula = formula, linewidth = 0.5) +
 #'   stat_quant_eq(formula = formula)
 #'
 #' ggplot(my.data, aes(x, y2, color = group)) +
 #'   geom_point() +
-#'   stat_quant_band(formula = formula, size = 0.75) +
+#'   stat_quant_band(formula = formula, linewidth = 0.75) +
 #'   stat_quant_eq(formula = formula) +
 #'   theme_bw()
 #'
@@ -277,7 +281,7 @@
 #' ggplot(my.data, aes(x, y2,  shape = group, linetype = group,
 #'        grp.label = group)) +
 #'   geom_point() +
-#'   stat_quant_band(formula = formula, color = "black", size = 0.75) +
+#'   stat_quant_band(formula = formula, color = "black", linewidth = 0.75) +
 #'   stat_quant_eq(use_label(c("grp", "eq"), sep = "*\": \"*"),
 #'                 formula = formula) +
 #'   expand_limits(y = 3) +
@@ -286,7 +290,7 @@
 #' # using weights
 #' ggplot(my.data, aes(x, y, weight = w)) +
 #'   geom_point() +
-#'   stat_quant_line(formula = formula, size = 0.5) +
+#'   stat_quant_line(formula = formula, linewidth = 0.5) +
 #'   stat_quant_eq(formula = formula)
 #'
 #' # no weights, quantile set to upper boundary
@@ -300,7 +304,7 @@
 #'   geom_point() +
 #'   stat_quant_line(method = "rq", formula = formula,
 #'                 quantiles = c(0.05, 0.5, 0.95),
-#'                 size = 0.5) +
+#'                 linewidth = 0.5) +
 #'   stat_quant_eq(aes(label = paste(after_stat(grp.label), "*\": \"*",
 #'                                    after_stat(eq.label), sep = "")),
 #'                 quantiles = c(0.05, 0.5, 0.95),
@@ -481,6 +485,17 @@ quant_eq_compute_group_fun <- function(data,
 
   force(data)
   force(method)
+
+  # parse obeys this option, but as for some labels or output types we do not
+  # use parse() to avoid dropping of trailing zeros, we need to manage this in
+  # our code in this case.
+  decimal.mark <- getOption("OutDec", default = ".")
+  if (!decimal.mark %in% c(".", ",")) {
+    warning("Decimal mark must be one of '.' or ',', not: '", decimal.mark, "'")
+    decimal.mark <- "."
+  }
+#  range.sep <- c("." = ", ", "," = "; ")[decimal.mark]
+
   num.quantiles <- length(quantiles)
 
   # make sure quantiles are ordered
@@ -489,7 +504,7 @@ quant_eq_compute_group_fun <- function(data,
   # factor with nicely formatted labels
   quant.digits <- ifelse(min(quantiles) < 0.01 || max(quantiles) > 0.99, 3, 2)
   quant.levels <- sort(unique(quantiles), decreasing = TRUE)
-  quant.labels <- sprintf("%#.*f", quant.digits, quant.levels)
+  quant.labels <- sprintf_dm("%#.*f", quant.digits, quant.levels, decimal.mark = decimal.mark)
   quantiles.f <- factor(quantiles,
                         levels = quant.levels,
                         labels = quant.labels)
@@ -644,7 +659,7 @@ quant_eq_compute_group_fun <- function(data,
   }
 
   formula <- formula.ls[[1]]
-  stopifnot(isa(formula, "formula"))
+  stopifnot(inherits(formula, what = "formula"))
 
   formula.rhs.chr <- as.character(formula)[3]
   forced.origin <- grepl("-[[:space:]]*1|+[[:space:]]*0", formula.rhs.chr)
@@ -698,14 +713,15 @@ quant_eq_compute_group_fun <- function(data,
                                   coef.keep.zeros = coef.keep.zeros,
                                   eq.x.rhs = eq.x.rhs,
                                   lhs = lhs,
-                                  output.type = output.type)
+                                  output.type = output.type,
+                                  decimal.mark = decimal.mark)
 
       if (output.type == "expression" && coef.keep.zeros) {
-        AIC.char[q] <- sprintf("\"%.4g\"", AIC[q])
-        rho.char[q] <- sprintf("\"%#.3g\"", rho[q])
+        AIC.char[q] <- sprintf_dm("\"%.4g\"", AIC[q], decimal.mark = decimal.mark)
+        rho.char[q] <- sprintf_dm("\"%#.3g\"", rho[q], decimal.mark = decimal.mark)
       } else {
-        AIC.char[q] <- sprintf("%.4g", AIC[q])
-        rho.char[q] <- sprintf("%#.3g", rho[q])
+        AIC.char[q] <- sprintf_dm("%.4g", AIC[q], decimal.mark = decimal.mark)
+        rho.char[q] <- sprintf_dm("%#.3g", rho[q], decimal.mark = decimal.mark)
       }
     }
 
@@ -717,10 +733,10 @@ quant_eq_compute_group_fun <- function(data,
                           n.label = paste("italic(n)~`=`~", n, sep = ""),
                           grp.label = if (any(grp.label != ""))
                                          paste(grp.label,
-                                            sprintf("italic(q)~`=`~\"%.2f\"", quantiles),
+                                            sprintf_dm("italic(q)~`=`~\"%.2f\"", quantiles, decimal.mark = decimal.mark),
                                             sep = "*\", \"*")
                                       else
-                                        sprintf("italic(q)~`=`~\"%.2f\"", quantiles),
+                                        sprintf_dm("italic(q)~`=`~\"%.2f\"", quantiles, decimal.mark = decimal.mark),
                           method.label = paste("\"method: ", method.name, "\"", sep = ""),
                           rq.method = rq.method,
                           quantile = quantiles,
@@ -732,7 +748,7 @@ quant_eq_compute_group_fun <- function(data,
                           rho.label = paste("rho", AIC.char, sep = " = "),
                           n.label = paste("n = ", n, sep = ""),
                           grp.label = paste(grp.label,
-                                            sprintf("q = %.2f", quantiles)),
+                                            sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
                           method.label = paste("method: ", method.name, sep = ""),
                           rq.method = rq.method,
                           quantile = quantiles,
@@ -744,7 +760,7 @@ quant_eq_compute_group_fun <- function(data,
                           rho.label = paste("rho", AIC.char, sep = " = "),
                           n.label = paste("_n_ = ", n, sep = ""),
                           grp.label = paste(grp.label,
-                                            sprintf("q = %.2f", quantiles)),
+                                            sprintf_dm("q = %.2f", quantiles, decimal.mark = decimal.mark)),
                           method.label = paste("method: ", method.name, sep = ""),
                           rq.method = rq.method,
                           quantile = quantiles,
@@ -876,6 +892,7 @@ StatQuantEq <-
                                   label = after_stat(eq.label),
                                   hjust = "inward",
                                   vjust = "inward"),
+                   dropped_aes = "weight",
                    required_aes = c("x", "y"),
                    optional_aes = "grp.label"
   )
